// AUTOGENERATED FILE - DO NOT MODIFY!
// This file generated by Djinni from com_verifone_commerce_entities.djinni

#pragma once

#include <cstdint>
#include <memory>
#include <optional>
#include <string>
#include <vector>

namespace verifone_sdk {

enum class EncryptionType;

/**
 * Allows an application to specify how to encrypt either sensitive card
 * information or an entire message for the retrieved ADE encrypted message.
 */
class AdeEncryption {
public:
    virtual ~AdeEncryption() {}

    /**
     *Encryption Options bit mapped flags passed as hex strings:
     *Data padding with 0x00: XX XX XX XX 00 00 00 00
     */
    static std::string const ENCRYPTION_OPTION_DATA_PADDING_00;

    /**Data padding with 0xff: XX XX XX XX ff ff ff ff */
    static std::string const ENCRYPTION_OPTION_DATA_PADDING_FF;

    /**Truncate PAN (TLV tag 5A): 123456789FFFF =&gt; 123456789F */
    static std::string const ENCRYPTION_OPTION_TRUNCATE_PAN;

    /**Add empty tags (with length 0) to result */
    static std::string const ENCRYPTION_OPTION_ADD_EMPTY_TAGS;

    /**Truncate values if data exceeds the fixed length */
    static std::string const ENCRYPTION_OPTION_TRUNCATE;

    /**
     *Use the associated value only, without tag or length information.  Not allowed if requesting
     *more than one tag and one or more tags are requested as variable length.
     */
    static std::string const ENCRYPTION_OPTION_VALUE_ONLY;

    /**
     *Format MSR Track 2 (TLV tag 57) according to the EMV Track 2 Equivalent Data spec.
     *For CT and CTLS, this has no effect as they are already in the expected EMV format.
     *When not used with MSR, Track2 will contain start and end sentinels and LRC.
     */
    static std::string const ENCRYPTION_OPTION_TRACK2_EMV;

    /**
     *Format CVV as an ASCII string with no padding and no null terminator.
     *When not used, CVV will be in BCD, with trailing F for odd length values
     */
    static std::string const ENCRYPTION_OPTION_CVV_ASCII;

    /**
     *Format PAN as an ASCII string with no padding and no null terminator.
     *When not used, PAN will be in BCD, with trailing F for odd length values
     */
    static std::string const ENCRYPTION_OPTION_PAN_ASCII;

    /**
     *Format Track 2 as an ASCII string with no padding and no null terminator.
     *When not used, Track2 will be in BCD, with trailing F for odd length values
     */
    static std::string const ENCRYPTION_OPTION_TRACK2_ASCII;

    /**Format Expiry Date (TLV tag 5F24) as an ASCII string with no padding */
    static std::string const ENCRYPTION_OPTION_EXPIRY_ASCII;

    /**
     *Format Track 2 as an ASCII string according to MSR spec with start ';' and end '?' sentinels
     *but with no LRC or padding
     */
    static std::string const ENCRYPTION_OPTION_TRACK2_ASCII_MSR;

    /**
     *Format Track1 equivalent data (TLV tag 56) according the EMV Track 1 Equivalent Data spec.
     *For CT and CTLS, this has no effect as they are already in the expected EMV format.
     *When not used with MSR, Track1 will contain start and end sentinels and LRC.
     */
    static std::string const ENCRYPTION_OPTION_TRACK1_EMV;

    static std::shared_ptr<AdeEncryption> create();

    /**Set encryption mode to either data encryption or message encryption */
    virtual void setEncryptionMode(EncryptionType mode) = 0;

    /**Set name of crypto interface */
    virtual void setCryptoInterface(const std::string & name) = 0;

    /**Set hex message to be inserted into EncryptMessage container */
    virtual void setHexMessageField(const std::vector<uint8_t> & value) = 0;

    /**Set text message to be inserted into EncryptMessage container */
    virtual void setTextMessageField(const std::string & value) = 0;

    /** Add TLV values and lengths for EncryptData TLV data */
    virtual void addEncryptDataTags(const std::string & value, int32_t length) = 0;

    /** Set Data Options for EncryptData TLV data */
    virtual void setEncryptDataOptions(const std::string & options) = 0;

    /** Add positional tag values and lengths for EncryptMessage sensitive data */
    virtual void addEncryptMessageTags(const std::string & value, int32_t length, const std::string & options, int32_t position) = 0;

    /** Specify the key to use as hex string */
    virtual void setKeySetId(const std::string & id) = 0;

    /**Set initialization vector as hex string */
    virtual void setInitializationVector(const std::optional<std::string> & iv) = 0;
};

}  // namespace verifone_sdk
